@@ -10,8 +10,6 @@ sub parse {
     $self->{version} = $version;
 }
 
-sub is_mobile { 0 }
-
 1;
 __END__
 
@@ -35,8 +33,6 @@ implements non-mobile or unimplemented user agents.
 
 See L<HTTP::MobileAgent/"METHODS"> for common methods.
 
-=back
-
 =head1 AUTHOR
 
 Tatsuhiko Miyagawa E<lt>miyagawa@bulknews.netE<gt>
